package com.aconiac.apg.domain;
/**
 * Password Generator interface
 *
 * @author Morten Slot Kristensen
 * 
 * Created December 1st 2007
 * 
 * Responsibilities:
 *  - To generate passwords
 *  - To seed passwords
 *  - To check the strength of passwords
 */

import java.util.*;

public interface PasswordGenerator {
    /**
     * Generate a password upon defined seed and character set with a
     * certain amount of entropy bits pr. symbol. If neither is
     * explicitly set by user the default character set is
     * [a-z][A-Z][0-9] and the default amount of entropy bits
     * pr. symbol is 5
     * @param length The length of the password
     * @return Generated password in a string
     */
    public String generate(int length);

    /**
     * Check the strength of a password
     *
     * @param passwordLength The length of the password
     * @param characterSetSize The amount of symbols in the character set
     * @return Strength of password in entropy bits
     */
    public double checkStrength(int passwordLength, int characterSetSize);

    /**
     * Get a description of the strength of a password from the entropy bits
     * @param entropyBits The entropy bits to evaluate on
     * @return The description of the strength of a password
     */
    public String strengthDescription(double entropyBits);

    /**
     * Seed the generator
     * @param seed The seed to seed the generator with
     */
    public void setSeed(long seed);

    /**
     * Define the characer set to use for the generation of the password
     * @param characterSet The character set to use
     */
    public void setCharacterSet(String characterSet);

    /**
     * Gets the character set
     * @return Character set
     */
    public String getCharacterSet();

    /**
     * Add a rule the password has to comply
     * @param rule The rule to add
     */
    public void addRule(Rule rule);

    /**
     * Remove a rule
     * @param rule The rule to remove
     */
    public void removeRule(Rule rule);

    /**
     * Get the list of rules
     * @return The list of rules
     */
    public ArrayList<Rule> getRuleList();
}